@@ -71,6 +71,7 @@ st_strsize (const void *s)
 int
 st_strcmp (const void *a, const void *b, void *data)
 {
+    (void)data;
     /* --- string comparison function */
     const char *s = a, *t = b;    /* to traverse the strings */
 
@@ -117,6 +118,7 @@ st_strhash (const void *s, int type)
 size_t
 st_intsize (const void *k)
 {
+    (void)k;
     return sizeof(int);    /* --- integer size function */
 }
 
@@ -125,6 +127,7 @@ st_intsize (const void *k)
 int
 st_intcmp (const void *a, const void *b, void *data)
 {
+    (void)data;
     /* --- integer comparison function */
     return (*(const int*)a == *(const int*)b) ? 0 : -1;
 }  /* st_intcmp() */
@@ -145,6 +148,7 @@ st_inthash (const void *k, int type)
 size_t
 st_lngsize (const void *k)
 {
+    (void)k;
     return sizeof(long);    /* --- long integer size function */
 }
 
@@ -153,6 +157,7 @@ st_lngsize (const void *k)
 int
 st_lngcmp (const void *a, const void *b, void *data)
 {
+    (void)data;
     /* --- long comparison function */
     return (*(const long*)a == *(const long*)b) ? 0 : -1;
 }  /* st_lngcmp() */
@@ -173,6 +178,7 @@ st_lnghash (const void *k, int type)
 size_t
 st_sizsize (const void *k)
 {
+    (void)k;
     return sizeof(size_t);    /* --- size_t size function */
 }
 
@@ -181,6 +187,7 @@ st_sizsize (const void *k)
 int
 st_sizcmp (const void *a, const void *b, void *data)
 {
+    (void)data;
     /* --- size_t comparison function */
     return (*(const size_t*)a == *(const size_t*)b) ? 0 : -1;
 }  /* st_sizcmp() */
@@ -201,6 +208,7 @@ st_sizhash (const void *k, int type)
 size_t
 st_difsize (const void *k)
 {
+    (void)k;
     return sizeof(ptrdiff_t);    /* --- ptrdiff_t size function */
 }
 
@@ -209,6 +217,7 @@ st_difsize (const void *k)
 int
 st_difcmp (const void *a, const void *b, void *data)
 {
+    (void)data;
     /* --- size_t comparison function */
     return (*(const ptrdiff_t*)a == *(const ptrdiff_t*)b) ? 0 : -1;
 }  /* st_difcmp() */
@@ -229,6 +238,7 @@ st_difhash (const void *k, int type)
 size_t
 st_ptrsize (const void *p)
 {
+    (void)p;
     return sizeof(void*);    /* --- pointer size function */
 }
 
@@ -237,6 +247,7 @@ st_ptrsize (const void *p)
 int
 st_ptrcmp (const void *a, const void *b, void *data)
 {
+    (void)data;
     /* --- pointer comparison function */
     return (a == b) ? 0 : -1;     /* return whether pointers are equal */
 }  /* st_ptrcmp() */
